@@ -30,30 +30,6 @@ LIST = [
      'title': N_('CMS'),
      'descr': N_('Content Management Systems'),
      'list':  [
-            {'name':  'drupal',
-             'title': N_('Drupal'),
-             'descr': N_('CMS for everything from personal weblogs to large community-driven websites.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'wordpress',
-             'title': N_('WordPress'),
-             'descr': N_('State-of-the-art publishing platform with a focus on aesthetics, web standards, and usability.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'joomla',
-             'title': N_('Joomla'),
-             'descr': N_('Build Web sites and powerful online applications'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'mediawiki',
-             'title': N_('MediaWiki Wiki'),
-             'descr': N_('Free software wiki package written in PHP, originally for use on Wikipedia.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'moinmoin',
-             'title': N_('MoinMoin Wiki'),
-             'descr': N_('Advanced, easy to use and extensible WikiEngine with a large community of users.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'trac',
-             'title': N_('Trac Bug Tracker System'),
-             'descr': N_('Enhanced wiki and issue tracking system for software development projects.'),
-             'type':  TYPE_VSERVER},
             {'name':  'concrete5',
              'title': N_('Concrete 5'),
              'descr': N_('The CMS made for Marketing, but built for Geeks.'),
@@ -69,10 +45,6 @@ LIST = [
              'title': N_('Alfresco'),
              'descr': N_('Enterprise web platform for building business solutions.'),
              'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'liferay',
-             'title': N_('Liferay'),
-             'descr': N_('Enterprise web platform for building business solutions.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
             {'name':  'glassfish',
              'title': N_('Glassfish'),
              'descr': N_('The first compatible implementation of the Java EE 6 platform specification.'),
@@ -130,26 +102,10 @@ LIST = [
      'title': N_('Web Applications'),
      'descr': N_('General Purpose Applications'),
      'list':  [
-            {'name':  'phpmyadmin',
-             'title': N_('phpMyAdmin'),
-             'descr': N_('PHP web application to handle the administration of MySQL.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
             {'name':  'mailman',
              'title': N_('GNU MailMan'),
              'descr': N_('Free software for managing electronic mail discussion and e-newsletter lists.'),
              'type':  TYPE_VSERVER},
-            {'name':  'moodle',
-             'title': N_('Moodle'),
-             'descr': N_('Course Management System / Virtual Learning Environment.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'phpbb',
-             'title': N_('phpBB Forum'),
-             'descr': N_('The most widely used Open Source forum solution.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
-            {'name':  'sugar',
-             'title': N_('Sugar CRM'),
-             'descr': N_('Enable organizations to efficiently organize customer relationships.'),
-             'type':  TYPE_VSERVER | TYPE_RULE},
             {'name':  'rtorrent',
              'title': N_('rTorrent'),
              'descr': N_('BitTorrent client written in C++, based on the libTorrent libraries for Unix.'),
